summaryrefslogtreecommitdiff
path: root/src/w32dlib
diff options
context:
space:
mode:
authorIan C <ianc@noddybox.co.uk>2005-04-17 00:34:01 +0000
committerIan C <ianc@noddybox.co.uk>2005-04-17 00:34:01 +0000
commit7740ebb87b8aa440f10095a77fea5d781844dd97 (patch)
tree29c43f23bcb957d3177db1282d8db5e44b79dee9 /src/w32dlib
parentba88028c9e6f7a2da0b9bc31e86ca9633613745e (diff)
Added Registry class and default message box titles
Diffstat (limited to 'src/w32dlib')
-rw-r--r--src/w32dlib/base.h2
-rw-r--r--src/w32dlib/common.h30
-rw-r--r--src/w32dlib/w32dlib.h1
3 files changed, 26 insertions, 7 deletions
diff --git a/src/w32dlib/base.h b/src/w32dlib/base.h
index 639c368..fb0af32 100644
--- a/src/w32dlib/base.h
+++ b/src/w32dlib/base.h
@@ -32,7 +32,7 @@
#include <sstream>
#endif
-/// \brief W32DLib Implements a simple wrapper around common Windows
+/// \brief W32DLib Implements a simple wrapper around some common Windows
/// dialog functionality.
///
namespace W32DLib
diff --git a/src/w32dlib/w32dlib.h b/src/w32dlib/w32dlib.h
index 41d53d0..47f0de2 100644
--- a/src/w32dlib/w32dlib.h
+++ b/src/w32dlib/w32dlib.h
@@ -33,6 +33,7 @@
#include <w32dlib/common.h>
#include <w32dlib/combobox.h>
#include <w32dlib/radiobutton.h>
+#include <w32dlib/registry.h>
#endif // W32DLIB_H
diff --git a/src/w32dlib/common.h b/src/w32dlib/common.h
index 7f49c08..de5364f 100644
--- a/src/w32dlib/common.h
+++ b/src/w32dlib/common.h
@@ -40,10 +40,23 @@ namespace W32DLib
static void Initialise();
+ /// \brief Sets the default titles for message boxes.
+ ///
+ /// All MessageBox type calls provide a default title if non is
+ /// provided. Using this you can set the default title to an
+ /// application specific one.
+ ///
+ /// \param title The default title. This pointer must remain valid
+ /// throughout the life of the application.
+ ///
+ static void MessageTitle(const char *title);
+
+
/// \brief Displays a message box.
///
/// \param parent Parent window (NULL for none)
/// \param title The title to display (NULL for default "Message")
/// \param msg The message to display.
///
static void Message(HWND parent, const char *title,
@@ -53,7 +66,8 @@ namespace W32DLib
/// \brief Displays a message box.
///
/// \param parent Parent window (NULL for none)
/// \param title The title to display (NULL for default "Message")
/// \param msg The message to display.
///
static void Message(HWND parent, const char *title,
@@ -63,7 +77,8 @@ namespace W32DLib
/// \brief Displays an error message box.
///
/// \param parent Parent window (NULL for none)
/// \param title The title to display (NULL for default "Error")
/// \param msg The error message to display.
///
static void Error(HWND parent, const char *title,
@@ -73,7 +88,8 @@ namespace W32DLib
/// \brief Displays an error message box.
///
/// \param parent Parent window (NULL for none)
/// \param title The title to display (NULL for default "Error")
/// \param msg The error message to display.
///
static void Error(HWND parent, const char *title,
@@ -83,7 +99,8 @@ namespace W32DLib
/// \brief Displays a Yes/No message box.
///
/// \param parent Parent window (NULL for none)
/// \param title The title to display (NULL for default "Question")
/// \param msg The message to display.
/// \return True if the user selects Yes.
///
@@ -94,7 +111,8 @@ namespace W32DLib
/// \brief Displays a Yes/No message box.
///
/// \param parent Parent window (NULL for none)
/// \param title The title to display (NULL for default "Question")
/// \param msg The message to display.
/// \return True if the user selects Yes.
///
@@ -40,10 +40,23 @@ namespace W32DLib
///
/// \param parent Parent window (NULL for none)
- /// \param title The title to display (NULL for default "Message")
+ /// \param title The title to display. NULL for default ("Message") or
+ /// to use the default supplied to MessageTitle().
/// \param msg The message to display.
///
@@ -53,7 +66,8 @@ namespace W32DLib
///
/// \param parent Parent window (NULL for none)
- /// \param title The title to display (NULL for default "Message")
+ /// \param title The title to display. NULL for default ("Message") or
+ /// to use the default supplied to MessageTitle().
/// \param msg The message to display.
///
@@ -63,7 +77,8 @@ namespace W32DLib
///
/// \param parent Parent window (NULL for none)
- /// \param title The title to display (NULL for default "Error")
+ /// \param title The title to display. NULL for default ("Error") or
+ /// to use the default supplied to MessageTitle().
/// \param msg The error message to display.
///
@@ -73,7 +88,8 @@ namespace W32DLib
///
/// \param parent Parent window (NULL for none)
- /// \param title The title to display (NULL for default "Error")
+ /// \param title The title to display. NULL for default ("Error") or
+ /// to use the default supplied to MessageTitle().
/// \param msg The error message to display.
///
@@ -83,7 +99,8 @@ namespace W32DLib
///
/// \param parent Parent window (NULL for none)
- /// \param title The title to display (NULL for default "Question")
+ /// \param title The title to display. NULL for default ("Question") or
+ /// to use the default supplied to MessageTitle().
/// \param msg The message to display.
/// \return True if the user selects Yes.
@@ -94,7 +111,8 @@ namespace W32DLib
///
/// \param parent Parent window (NULL for none)
- /// \param title The title to display (NULL for default "Question")
+ /// \param title The title to display. NULL for default ("Question") or
+ /// to use the default supplied to MessageTitle().
/// \param msg The message to display.
/// \return True if the user selects Yes.